import { useMemo, useState } from 'react';
import { HSegmentedControl } from '../../components/HSegmentedControl';
import { Labeled } from '../../components/Labeled';
import { ScrollArea } from '../../components/ScrollArea';
import { useCopy } from '../../hooks/useCopy';
import { Option, SchemeContent, SchemeStorage } from '../../models';
import styles from './Export.module.css';

const exportOptions: Option[] = [
  { label: 'CSS', value: 'css' },
  { label: 'SCSS', value: 'scss' },
  { label: 'Javascript Object', value: 'js_object' },
];

type SchemeExportProps = {
  scheme: SchemeContent<SchemeStorage>;
};

export function SchemeExport({ scheme }: SchemeExportProps) {
  const [activeExport, setActiveExport] = useState<Option['value']>(exportOptions[0].value);
  const exportContent = useMemo(() => {
    switch (activeExport) {
      case 'css':
        return scheme.schemeStorage.cssVariables;
      case 'scss':
        return scheme.schemeStorage.scssVariables;
      case 'js_object':
        return scheme.schemeStorage.jsVariables;
    }
  }, [scheme, activeExport]);
  const copyToClipboard = useCopy();

  return (
    <ScrollArea enableY>
      <div className={styles.export_layout}>
        <div className={styles.tools}>
          <Labeled label="Export Options" inline>
            <HSegmentedControl
              options={exportOptions}
              value={activeExport}
              onChange={setActiveExport}
            />
          </Labeled>
          <button onClick={() => copyToClipboard(exportContent)}>Copy</button>
        </div>
        <pre>{exportContent}</pre>
      </div>
    </ScrollArea>
  );
}
