import { ScrollArea } from '../../../components/ScrollArea';
import { SchemeContent } from '../../../models';
import { SwatchSchemeStorage } from '../../../swatch_scheme';
import styles from './Preview.module.css';

type SwatchCellProps = {
  color: string;
};

export function SwatchCell({ color }: SwatchCellProps) {
  return (
    <div className={styles.scheme_cell}>
      <div className={styles.block} style={{ backgroundColor: `#${color}` }} />
    </div>
  );
}

type SchemeBlockProps = {
  amount: number;
  scheme: Record<string, string[]>;
};

export function SchemeBlock({ amount, scheme }: SchemeBlockProps) {
  return (
    <div
      className={styles.scheme_block}
      style={{ gridTemplateColumns: `minmax(120px, 1fr) repeat(${amount}, 1fr)` }}>
      <div />
      {Array.from({ length: amount }).map((_, index) => (
        <div key={index} className={styles.scheme_cell}>
          <div className={styles.label}>{index * 100}</div>
        </div>
      ))}
      {Object.entries(scheme).map(([name, colors]) => (
        <>
          <h6>{name}</h6>
          {colors.map((color, index) => (
            <SwatchCell key={index} color={color} />
          ))}
        </>
      ))}
    </div>
  );
}

type SwatchSchemePreviewProps = {
  scheme: SchemeContent<SwatchSchemeStorage>;
};

export function SwatchSchemePreview({ scheme }: SwatchSchemePreviewProps) {
  return (
    <ScrollArea enableY>
      <div className={styles.preview_layout}>
        <h2>Light Scheme</h2>
        <SchemeBlock
          amount={scheme.schemeStorage.source?.setting?.amount ?? 0}
          scheme={scheme.schemeStorage.scheme.light}
        />
        <h2>Dark Scheme</h2>
        <SchemeBlock
          amount={scheme.schemeStorage.source?.setting?.amount ?? 0}
          scheme={scheme.schemeStorage.scheme.dark}
        />
      </div>
    </ScrollArea>
  );
}
