import { isEmpty, isNil } from 'lodash-es';

export function defaultEmptyFormData<D>(formData: FormData, param: string, defaultValue: D): D {
  const value = formData.get(param);
  if (isNil(value) || isEmpty(value)) {
    return defaultValue;
  }
  return value;
}

export function defaultEmptyValue<T, D>(value: T, defaultValue: D): T | D {
  if (isNil(value) || isEmpty(value)) {
    return defaultValue;
  }
  return value;
}

export function mapToObject<K extends string | number | symbol, V>(
  map: Map<K, V>,
): Record<K, V extends Map<unknown, unknown> ? unknown : V> {
  const obj: Record<K, V extends Map<unknown, unknown> ? unknown : V> = {};
  map.forEach((value, key) => {
    if (value instanceof Map) {
      obj[key] = mapToObject(value);
    } else {
      obj[key] = value;
    }
  });
  return obj;
}
